@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: statistics
 version: 0.13.2.3
-id: statistics-0.13.2.3-781c9ad2296cc7a41c5283491bb54b0b
-key: stati_5gFPd48mSRD9KxpJPM1IFG
+id: statistics-0.13.2.3-2e9fffd6a9f27438d40641d2910361be
+key: stati_IIEfRaGdwj50y9gMTGa8JU
 license: BSD3
 copyright: 2009-2014 Bryan O'\''Sullivan
 maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
@@ -63,9 +63,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/statistics-0.13.2.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/statistics-0.13.2.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/statistics-0.13.2.3
-hs-libraries: HSstatistics-0.13.2.3-5gFPd48mSRD9KxpJPM1IFG
+hs-libraries: HSstatistics-0.13.2.3-IIEfRaGdwj50y9gMTGa8JU
 depends:
-    aeson-0.11.0.0-3b69ab8a9952fc7c94fde12b431d717b
+    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
@@ -76,7 +76,7 @@ depends:
     primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
     vector-algorithms-0.7.0.1-7844ad1f07fd0916dddd070104841af1
-    vector-binary-instances-0.2.1.1-c0febfb5ca69d46d3d7932a3e5b87de1
+    vector-binary-instances-0.2.3.1-2255e15260ecf66ec12e6381e175b94d
 haddock-interfaces: /usr/share/doc/haskell-statistics/html/statistics.haddock
 haddock-html: /usr/share/doc/haskell-statistics/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
